@@ -161,10 +161,6 @@ ido_entry_menu_item_send_focus_change (GtkWidget *widget,
 {
   GdkEvent *event = gdk_event_new (GDK_FOCUS_CHANGE);
 
-  gdk_keyboard_ungrab (GDK_CURRENT_TIME);
-
-  gdk_keyboard_grab (widget->window, TRUE, GDK_CURRENT_TIME);
-
   g_object_ref (widget);
 
   event->focus_change.type = GDK_FOCUS_CHANGE;
@@ -173,6 +169,8 @@ ido_entry_menu_item_send_focus_change (GtkWidget *widget,
 
   gtk_widget_event (widget, event);
 
+  g_object_notify (G_OBJECT (widget), "has-focus");
+
   g_object_unref (widget);
   gdk_event_free (event);
 }
@@ -183,10 +181,13 @@ ido_entry_menu_item_button_press (GtkWidget      *widget,
 {
   GtkWidget *entry = IDO_ENTRY_MENU_ITEM (widget)->priv->entry;
 
-  ido_entry_menu_item_send_focus_change (widget, TRUE);
-
   if (event->button == 1)
     {
+      if (entry->window != NULL)
+        {
+          gdk_window_raise (entry->window);
+        }
+
       if (!gtk_widget_has_focus (entry))
         {
           gtk_widget_grab_focus (entry);
